"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useInputScrollHandler;

var _react = require("react");

var _reactNative = require("react-native");

const _keyboardWillShow = _reactNative.Platform.select({
  ios: 'keyboardWillShow',
  android: 'keyboardDidShow',
  default: 'keyboardWillShow'
});

const _keyboardWillHide = _reactNative.Platform.select({
  ios: 'keyboardWillHide',
  android: 'keyboardDidHide',
  default: 'keyboardWillHide'
});

function useInputScrollHandler() {
  var _options$ref;

  let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  // Refs
  const ref = (0, _react.useRef)(((_options$ref = options.ref) === null || _options$ref === void 0 ? void 0 : _options$ref.current) ?? null);
  const offset = (0, _react.useRef)();
  const handledOffset = (0, _react.useRef)(); // Window

  const screen = (0, _reactNative.useWindowDimensions)(); // Variables

  const extraScrollHeight = (options === null || options === void 0 ? void 0 : options.extraScrollHeight) ?? 0;
  const keyboardOpeningTime = (options === null || options === void 0 ? void 0 : options.keyboardOpeningTime) ?? 250; // States

  const [keyboardSpace, setKeyboardSpace] = (0, _react.useState)(0);
  const [isScrolling, setIsScrolling] = (0, _react.useState)(false); // Functions

  const getScrollResponder = () => {
    var _ref$current;

    const responder = (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.getScrollResponder();
    return responder;
  };

  const scrollToFocusedInput = (reactNode, additionalOffset) => {
    setTimeout(() => {
      const responder = getScrollResponder();
      responder && responder.scrollResponderScrollNativeHandleToKeyboard(reactNode, additionalOffset + extraScrollHeight, false);
    }, keyboardOpeningTime);
  };

  const scrollToFocusedInputWithNodeHandle = (nodeID, additionalOffset) => {
    const reactNode = (0, _reactNative.findNodeHandle)(nodeID);
    scrollToFocusedInput(reactNode, additionalOffset);
  };

  const handleOnScroll = e => {
    offset.current = e.nativeEvent.contentOffset;
  };

  const handleUpdateKeyboardSpace = (e, isScrolling) => {
    // @ts-ignore
    if (isScrolling) {
      return;
    }

    setIsScrolling(true); // @ts-ignore

    const currentlyFocusedField = _reactNative.TextInput.State.currentlyFocusedInput() ? // @ts-ignore
    (0, _reactNative.findNodeHandle)(_reactNative.TextInput.State.currentlyFocusedInput()) : _reactNative.TextInput.State.currentlyFocusedField();
    const responder = getScrollResponder();

    if (!currentlyFocusedField || !responder) {
      return;
    }

    handledOffset.current = offset.current; // Calculate scroll view position

    _reactNative.UIManager.measure(responder.getScrollableNode(), (_scrollX, _scrollY, _scrollWidth, scrollHeight, _scrollPageX, scrollPageY) => {
      const bottomSpace = screen.height - (scrollPageY + scrollHeight);
      setKeyboardSpace(e.endCoordinates.height + extraScrollHeight - bottomSpace); // @ts-ignore

      _reactNative.UIManager.viewIsDescendantOf(currentlyFocusedField, responder.getInnerViewNode(), isAncestor => {
        if (!isAncestor) {
          return;
        }

        _reactNative.UIManager.measureInWindow(currentlyFocusedField, (_inputX, inputY, _inputWidth, inputHeight) => {
          const textInputBottomPosition = inputY + inputHeight;
          const keyboardPosition = e.endCoordinates.screenY;
          const totalExtraHeight = extraScrollHeight;

          if (_reactNative.Platform.OS === 'ios') {
            if (textInputBottomPosition > keyboardPosition - totalExtraHeight) {
              scrollToFocusedInputWithNodeHandle(currentlyFocusedField, scrollPageY);
            }
          } else {
            var _offset$current;

            responder.scrollTo({
              y: (((_offset$current = offset.current) === null || _offset$current === void 0 ? void 0 : _offset$current.y) ?? 0) + extraScrollHeight,
              animated: true
            });
          }
        });
      });

      setIsScrolling(false);
    });
  };

  const handleResetKeyboardSpace = () => {
    setKeyboardSpace(0);

    if (handledOffset.current) {
      const responder = getScrollResponder();
      responder.scrollTo({
        x: handledOffset.current.x,
        y: handledOffset.current.y,
        animated: true
      });
    }
  }; // Effects


  (0, _react.useEffect)(() => {
    const handleUpdate = e => {
      handleUpdateKeyboardSpace(e, isScrolling);
    };

    const handleReset = e => {
      // Set isScrolling state to false when keyboard closes
      setIsScrolling(false);
      handleResetKeyboardSpace(e);
    };

    _reactNative.Keyboard.addListener(_keyboardWillShow, handleUpdate);

    _reactNative.Keyboard.addListener(_keyboardWillHide, handleReset);

    return () => {
      _reactNative.Keyboard.removeListener(_keyboardWillShow, handleUpdate);

      _reactNative.Keyboard.removeListener(_keyboardWillHide, handleReset);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [isScrolling, setIsScrolling]);
  return {
    scrollHandler: {
      ref,
      contentContainerStyle: {
        paddingBottom: keyboardSpace
      },
      onScroll: handleOnScroll,
      scrollEventThrottle: 16
    },
    keyboardSpace
  };
}
//# sourceMappingURL=index.js.map